jQuery(document).ready(function($) {
    function loadModalContent() {
        $.ajax({
            url: ajaxurl,
            type: 'POST',
            data: {
                action: 'vrs20_stationbuilder_modal_content'
            },
            success: function(response) {
                $('#vrs20-stationbuilder-modal').html(response);
                initializeModalEvents();
                initializeSortable();
            }
        });
    }

    function initializeModalEvents() {
        $('#vrs20-add-url-form').submit(function(e) {
            e.preventDefault();
            var newUrl = $('#vrs20-new-url').val();
            
            // Validate URL
            var validProtocols = ['mms://', 'http://', 'https://', 'rtsp://', 'rtmp://'];
            var isValid = validProtocols.some(function(protocol) {
                return newUrl.toLowerCase().startsWith(protocol);
            });

            if (!isValid) {
                alert('Please enter a valid URL starting with mms://, http://, https://, rtsp://, or rtmp://');
                return;
            }

            $.ajax({
                url: ajaxurl,
                type: 'POST',
                data: {
                    action: 'vrs20_add_url',
                    nonce: $('#vrs20_url_nonce').val(),
                    url: newUrl
                },
                success: function(response) {
                    if (response.success) {
                        var newItem = '<li data-index="' + response.data.index + '">' +
                                      '<span class="vrs20-url-handle dashicons dashicons-move"></span>' +
                                      '<span class="vrs20-url-text">' + response.data.url + '</span>' +
                                      '<button class="vrs20-delete-url button button-small">Delete</button>' +
                                      '</li>';
                        $('#vrs20-url-list').append(newItem);
                        $('#vrs20-new-url').val('');
                    } else {
                        alert('Error: ' + response.data.message);
                    }
                }
            });
        });

        $('#vrs20-url-list').on('click', '.vrs20-delete-url', function() {
            var $li = $(this).closest('li');
            var index = $li.data('index');
            $.ajax({
                url: ajaxurl,
                type: 'POST',
                data: {
                    action: 'vrs20_delete_url',
                    index: index,
                    nonce: $('#vrs20_url_nonce').val()
                },
                success: function(response) {
                    if (response.success) {
                        $li.remove();
                        updateIndices();
                    } else {
                        alert(response.data.message);
                    }
                }
            });
        });

        $('#vrs20-save-order').on('click', function() {
            var order = [];
            $('#vrs20-url-list li').each(function(index) {
                order.push($(this).data('index'));
            });
            $.ajax({
                url: ajaxurl,
                type: 'POST',
                data: {
                    action: 'vrs20_save_url_order',
                    order: order,
                    nonce: $('#vrs20_url_nonce').val()
                },
                success: function(response) {
                    if (response.success) {
                        alert('URL order saved successfully');
                        updateIndices();
                    } else {
                        alert('Error saving URL order');
                    }
                }
            });
        });
    }

    function initializeSortable() {
        $('#vrs20-url-list').sortable({
            handle: '.vrs20-url-handle',
            update: function(event, ui) {
                // Optional: You can trigger an auto-save here if you want
                // $('#vrs20-save-order').click();
            }
        });
    }

    function updateIndices() {
        $('#vrs20-url-list li').each(function(index) {
            $(this).attr('data-index', index);
        });
    }

    loadModalContent();
});