<?php
if (!defined('ABSPATH')) {
    exit;
}
require_once plugin_dir_path(__FILE__) . 'config.php';

// Modify "Add New Post" to "Add New Stream"
function vrs20_modify_add_new_stream_label($labels) {
    $labels->add_new = 'Add New Stream';
    $labels->add_new_item = 'Add New Stream';
    return $labels;
}
add_filter('post_type_labels_vrs20_stream', 'vrs20_modify_add_new_stream_label');

// Add settings page
function vrs20_add_settings_page() {
    add_submenu_page(
        'edit.php?post_type=vrs20_stream',
        'VRS 2.0 Settings',
        'Settings',
        'manage_options',
        'vrs20_settings',
        'vrs20_settings_page'
    );

    // Add Terms and Conditions page
    add_submenu_page(
        'edit.php?post_type=vrs20_stream',
        'Terms and Conditions',
        'Terms and Conditions',
        'manage_options',
        'vrs20_terms_conditions',
        'vrs20_terms_conditions_page'
    );

    // Add upRiver Support page
    add_submenu_page(
        'edit.php?post_type=vrs20_stream',
        'upRiver Support',
        'upRiver Support',
        'manage_options',
        'vrs20_upriver_support',
        'vrs20_upriver_support_page'
    );

    // Add StationBuilder Playlist Management page
    add_submenu_page(
        'edit.php?post_type=vrs20_stream',
        'StationBuilder Playlist Management',
        'StationBuilder Playlist',
        'manage_options',
        'vrs20_stationbuilder_playlist',
        'vrs20_stationbuilder_playlist_page'
    );

    // Enqueue JavaScript for modal
    add_action('admin_enqueue_scripts', 'vrs20_enqueue_modal_scripts');
}
add_action('admin_menu', 'vrs20_add_settings_page');

// Enqueue necessary scripts
function vrs20_enqueue_modal_scripts($hook) {
    if ('vrs20_stream_page_vrs20_stationbuilder_playlist' !== $hook) {
        return;
    }
    wp_enqueue_script('jquery');
    wp_enqueue_script('jquery-ui-core');
    wp_enqueue_script('jquery-ui-dialog');
    wp_enqueue_script('jquery-ui-sortable');
    wp_enqueue_style('wp-jquery-ui-dialog');
    wp_enqueue_script('vrs20-modal-script', plugin_dir_url(__FILE__) . 'js/vrs20-modal.js', array('jquery', 'jquery-ui-dialog', 'jquery-ui-sortable'), '1.0', true);
}
// Settings page
function vrs20_settings_page() {
    if (isset($_POST['vrs20_settings_nonce']) && wp_verify_nonce($_POST['vrs20_settings_nonce'], 'vrs20_save_settings')) {
        // Save all options
        update_option('vrs20_base_url', esc_url_raw($_POST['vrs20_base_url']));
        update_option('vrs20_storage', isset($_POST['vrs20_storage']) ? $_POST['vrs20_storage'] : array());
        update_option('vrs20_stream_urls', isset($_POST['vrs20_stream_urls']) ? $_POST['vrs20_stream_urls'] : array());
        update_option('vrs20_stream_url_additional', array(
            'is_live' => isset($_POST['vrs20_stream_is_live']),
            'is_24_7' => isset($_POST['vrs20_stream_is_24_7']),
            'is_playlist_maintained' => isset($_POST['vrs20_stream_is_playlist_maintained'])
        ));
        update_option('vrs20_playlist', isset($_POST['vrs20_playlist']) ? $_POST['vrs20_playlist'] : array());
        update_option('vrs20_stream_link', array(
            'stream_key' => sanitize_text_field($_POST['vrs20_stream_key']),
            'live_url' => esc_url_raw($_POST['vrs20_live_url']),
            'auth_username' => sanitize_text_field($_POST['vrs20_auth_username']),
            'auth_password' => sanitize_text_field($_POST['vrs20_auth_password'])
        ));
        // Save Restream options
        update_option('vrs20_restream', array(
            'stream_url' => esc_url_raw($_POST['vrs20_restream_url']),
            'stream_key' => sanitize_text_field($_POST['vrs20_restream_key']),
            'auth_username' => sanitize_text_field($_POST['vrs20_restream_username']),
            'auth_password' => sanitize_text_field($_POST['vrs20_restream_password'])
        ));
        
        echo '<div class="notice notice-success"><p>Settings saved successfully!</p></div>';
    }

    // Get all options
    $base_url = get_option('vrs20_base_url', '');
    $storage_options = get_option('vrs20_storage', array());
    $stream_url_options = get_option('vrs20_stream_urls', array());
    $stream_url_additional = get_option('vrs20_stream_url_additional', array(
        'is_live' => false,
        'is_24_7' => false,
        'is_playlist_maintained' => false
    ));
    $playlist_options = get_option('vrs20_playlist', array());
    $stream_link_options = get_option('vrs20_stream_link', array(
        'stream_key' => '',
        'live_url' => '',
        'auth_username' => '',
        'auth_password' => ''
    ));
    $restream_options = get_option('vrs20_restream', array(
        'stream_url' => '',
        'stream_key' => '',
        'auth_username' => '',
        'auth_password' => ''
    ));
    ?>
    <div class="wrap">
        <h1>VRS 2.0 Settings</h1>
        <form method="post" action="">
            <?php wp_nonce_field('vrs20_save_settings', 'vrs20_settings_nonce'); ?>
            
            <h2>General Settings</h2>
            <table class="form-table">
                <tr>
                    <th><label for="vrs20_base_url">VRS 2.0 Base URL</label></th>
                    <td><input type="url" name="vrs20_base_url" id="vrs20_base_url" value="<?php echo esc_url($base_url); ?>" class="regular-text"></td>
                </tr>
            </table>
            
            <h2>Storage Options</h2>
            <table class="form-table">
                <tr>
                    <th>Storage Capacity</th>
                    <td>
                        <label><input type="checkbox" name="vrs20_storage[]" value="8TB" <?php checked(in_array('8TB', $storage_options)); ?>> 8 TB</label><br>
                        <label><input type="checkbox" name="vrs20_storage[]" value="20TB" <?php checked(in_array('20TB', $storage_options)); ?>> 20 TB</label><br>
                        <label><input type="checkbox" name="vrs20_storage[]" value="50TB" <?php checked(in_array('50TB', $storage_options)); ?>> 50 TB</label>
                    </td>
                </tr>
            </table>
            
            <h2>Stream URL Options</h2>
            <table class="form-table">
                <tr>
                    <th>Stream URLs</th>
                    <td>
                        <label><input type="checkbox" name="vrs20_stream_urls[]" value="main" <?php checked(in_array('main', $stream_url_options)); ?>> Main</label><br>
                        <label><input type="checkbox" name="vrs20_stream_urls[]" value="sub" <?php checked(in_array('sub', $stream_url_options)); ?>> Sub</label><br>
                        <label><input type="checkbox" name="vrs20_stream_urls[]" value="rollover" <?php checked(in_array('rollover', $stream_url_options)); ?>> Rollover</label>
                    </td>
                </tr>
                <tr>
                    <th>Additional Stream Options</th>
                    <td>
                        <label><input type="checkbox" name="vrs20_stream_is_live" <?php checked($stream_url_additional['is_live']); ?>> Is Live</label><br>
                        <label><input type="checkbox" name="vrs20_stream_is_24_7" <?php checked($stream_url_additional['is_24_7']); ?>> 24/7</label><br>
                        <label><input type="checkbox" name="vrs20_stream_is_playlist_maintained" <?php checked($stream_url_additional['is_playlist_maintained']); ?>> Is Playlist Maintained</label>
                    </td>
                </tr>
            </table>
            
            <h2>Playlist Options</h2>
            <table class="form-table">
                <tr>
                    <th>Playlist Features</th>
                    <td>
                        <?php
                        $playlist_features = array(
                            'multi-format' => 'Multi-Format',
                            'tts-switching' => 'TTS Switching',
                            'dedicated' => 'Dedicated',
                            'dynamic' => 'Dynamic',
                            'alternative' => 'Alternative',
                            'automated' => 'Automated',
                            'live-assist' => 'Live Assist',
                            'jock' => 'Jock',
                            'cyber-dj' => 'Cyber DJ',
                            'voice-assist' => 'Voice Assist',
                            'ai' => 'AI'
                        );
                        foreach ($playlist_features as $value => $label) {
                            echo '<label><input type="checkbox" name="vrs20_playlist[]" value="' . esc_attr($value) . '" ' . checked(in_array($value, $playlist_options), true, false) . '> ' . esc_html($label) . '</label><br>';
                        }
                        ?>
                    </td>
                </tr>
            </table>
            
            <h2>Stream Link</h2>
            <table class="form-table">
                <tr>
                    <th><label for="vrs20_stream_key">Stream Key</label></th>
                    <td><input type="text" name="vrs20_stream_key" id="vrs20_stream_key" value="<?php echo esc_attr($stream_link_options['stream_key']); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th><label for="vrs20_live_url">Live URL</label></th>
                    <td><input type="url" name="vrs20_live_url" id="vrs20_live_url" value="<?php echo esc_url($stream_link_options['live_url']); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th><label for="vrs20_auth_username">Custom Authentication Username</label></th>
                    <td><input type="text" name="vrs20_auth_username" id="vrs20_auth_username" value="<?php echo esc_attr($stream_link_options['auth_username']); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th><label for="vrs20_auth_password">Custom Authentication Password</label></th>
                    <td><input type="password" name="vrs20_auth_password" id="vrs20_auth_password" value="<?php echo esc_attr($stream_link_options['auth_password']); ?>" class="regular-text"></td>
                </tr>
            </table>
            
            <h2>Restream</h2>
            <table class="form-table">
                <tr>
                    <th><label for="vrs20_restream_url">Restream URL</label></th>
                    <td><input type="url" name="vrs20_restream_url" id="vrs20_restream_url" value="<?php echo esc_url($restream_options['stream_url']); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th><label for="vrs20_restream_key">Restream Key</label></th>
                    <td><input type="text" name="vrs20_restream_key" id="vrs20_restream_key" value="<?php echo esc_attr($restream_options['stream_key']); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th><label for="vrs20_restream_username">Restream Authentication Username</label></th>
                    <td><input type="text" name="vrs20_restream_username" id="vrs20_restream_username" value="<?php echo esc_attr($restream_options['auth_username']); ?>" class="regular-text"></td>
                </tr>
                <tr>
                    <th><label for="vrs20_restream_password">Restream Authentication Password</label></th>
                    <td><input type="password" name="vrs20_restream_password" id="vrs20_restream_password" value="<?php echo esc_attr($restream_options['auth_password']); ?>" class="regular-text"></td>
                </tr>
            </table>
            
            <?php submit_button('Save Settings'); ?>
        </form>
    </div>
    <?php
}

// Terms and Conditions page
function vrs20_terms_conditions_page() {
    $current_date = date('F j, Y');
    $user_id = get_current_user_id();
    $has_agreed = get_user_meta($user_id, 'vrs20_terms_agreed', true);
    ?>
    <div class="wrap">
        <h1>Terms and Conditions</h1>
        <button id="open-terms-modal" class="button button-primary">View Terms and Conditions</button>
        <div id="terms-modal" title="Terms and Conditions" style="display:none;">
            <!-- Content will be loaded here by JavaScript -->
        </div>
        <p id="agreement-status">
            <?php if ($has_agreed): ?>
                You have agreed to the Terms and Conditions on <?php echo $has_agreed; ?>.
            <?php else: ?>
                You have not yet agreed to the Terms and Conditions.
            <?php endif; ?>
        </p>
        <script type="text/javascript">
            var vrs20TermsAgreed = <?php echo json_encode($has_agreed); ?>;
        </script>
    </div>
    <?php
}

// Add an AJAX handler to update the agreement status
add_action('wp_ajax_vrs20_update_terms_agreement', 'vrs20_update_terms_agreement');
function vrs20_update_terms_agreement() {
    $user_id = get_current_user_id();
    $date = current_time('mysql');
    update_user_meta($user_id, 'vrs20_terms_agreed', $date);
    wp_send_json_success(array('date' => $date));
}

// Enqueue scripts for the Terms and Conditions page
function vrs20_enqueue_terms_modal_scripts($hook) {
    if ('vrs20_stream_page_vrs20_terms_conditions' !== $hook) {
        return;
    }
    wp_enqueue_script('jquery');
    wp_enqueue_script('jquery-ui-core');
    wp_enqueue_script('jquery-ui-dialog');
    wp_enqueue_style('wp-jquery-ui-dialog');
    wp_enqueue_script('vrs-modal-terms-cond', plugin_dir_url(__FILE__) . 'js/vrs20-modal-terms-cond.js', array('jquery', 'jquery-ui-dialog'), '1.0', true);
}
add_action('admin_enqueue_scripts', 'vrs20_enqueue_terms_modal_scripts');

// upRiver Support page
function vrs20_upriver_support_page() {
    ?>
    <div class="wrap">
        <h1>upRiver Support</h1>
        <center><a href="https://upriver.studio/service-level-agreements/">SLA Agreements</a><br>
    </center>
        <!-- Add your upRiver Support content here -->
        <center><H1>This is the upRiver Support page for VRS 2.0.</H1></center>
        
<div>
  <center><h1><a href="https://upriver.studio/support/" rel="bookmark">support</a></h1></center>
  <div> </div>
</div>
<div>
  <div><center>
    <h1>upRiver Support &amp; Options</h1>
    <hr>
    <h3>Create a New Support Ticket<br>
      <a href="https://upriver.studio/book-appt/" title="">Set up Appointment</a><br>
      <br>
      <a href="http://mtfnow.com/support-systems/" target="_blank" rel="noreferrer noopener">Reboot Request | Restart Player &amp; Chat | GoLive Broadcast Support</a></h3>
    <hr>
    <p><a href="https://support.mtfnow.com">SLA Support Tickets &amp; Issues Tracking</a><br>
    </p>
    <div>
      <div><a href="https://support.mtfnow.com" target="_blank" rel="noreferrer noopener">SLA Tickets &amp; Issues Tracking</a></div>
    </div>
    <hr>
    <p><strong><a href="https://upriver.studio/support/" data-type="page" data-id="3800">Support Options</a> Include <a href="https://upriver.studio/custom-streaming-control-systems/" data-type="post" data-id="4371">Custom Configurations</a> &amp; <a href="https://upriver.studio/business-model-offerings/" data-type="post" data-id="4424">Camera Master Control Systems</a> Profiles. <br>
      Backups / Version Controlled operations.   Access to <a href="https://upriver.studio/master-control/" data-type="page" data-id="3976">Master Control Systems</a></strong></p>
    <p><strong>Each   Services level has it&rsquo;s own SLA – Service Level Agreement.   It&rsquo;s the   way we do business that makes us different.   SLA is the key to having   your own channels and network management – <br>
      Master Control System.</strong> Check out the video of our network service levels. <a href="https://upriver.studio/service-level-agreements/" data-type="post" data-id="3530">Learn About SLA</a></p>
    <h2><a rel="noreferrer noopener" href="https://www.youtube.com/@upriver" data-type="link" data-id="https://www.youtube.com/@upriver" target="_blank">Youtube Channel</a><br>
      Facebook<br>
      <a rel="noreferrer noopener" href="http://mtfnow.com/support-systems/" target="_blank">Tech Farm</a><br>
      <a rel="noreferrer noopener" href="https://support.mtfnow.com" target="_blank">SLA Support</a><br>
      <a rel="noreferrer noopener" href="https://speedstream.tv/wizard/" target="_blank">Set Up Wizard</a><br>
      <a rel="noreferrer noopener" href="https://speedstream.tv/glossary" target="_blank">Glossary</a></h2>
  </div>
</div></center>
    </div>
    <?php
}

// StationBuilder Playlist Management page
function vrs20_stationbuilder_playlist_page() {
    ?>
    <div id="vrs20-stationbuilder-modal" title="StationBuilder Playlist Management" style="display:none;">
        <!-- Modal content will be loaded here -->
    </div>
    <script type="text/javascript">
        jQuery(document).ready(function($) {
            $("#vrs20-stationbuilder-modal").dialog({
                autoOpen: true,
                height: 600,
                width: 800,
                modal: true
            });
        });
    </script>
    <?php
}

// AJAX handler for modal content
function vrs20_stationbuilder_modal_content() {
    $urls = get_option('vrs20_stationbuilder_urls', array());

    ob_start();
    ?>
    <div id="vrs20-url-list-container">
        <h2>StationBuilder Playlist Management</h2>
        <form id="vrs20-add-url-form">
            <?php wp_nonce_field('vrs20_add_url', 'vrs20_url_nonce'); ?>
            <input type="url" id="vrs20-new-url" placeholder="Enter new URL" required>
            <button type="submit" class="button button-primary">Add URL</button>
        </form>
        <h3>Current URLs:</h3>
        <ul id="vrs20-url-list">
            <?php foreach ($urls as $index => $url): ?>
                <li data-index="<?php echo $index; ?>">
                    <span class="vrs20-url-handle dashicons dashicons-move"></span>
                    <span class="vrs20-url-text"><?php echo esc_url($url); ?></span>
                    <button class="vrs20-delete-url button button-small">Delete</button>
                </li>
            <?php endforeach; ?>
        </ul>
        <button id="vrs20-save-order" class="button button-primary">Save Order</button>
    </div>
    <?php
    $content = ob_get_clean();
    echo $content;
    wp_die();
}
add_action('wp_ajax_vrs20_stationbuilder_modal_content', 'vrs20_stationbuilder_modal_content');

// AJAX handler for adding URLs
function vrs20_add_url() {
    check_ajax_referer('vrs20_add_url', 'nonce');
    $new_url = esc_url_raw($_POST['url']);
    if ($new_url) {
        $urls = get_option('vrs20_stationbuilder_urls', array());
        $urls[] = $new_url;
        update_option('vrs20_stationbuilder_urls', $urls);
        wp_send_json_success(array('message' => 'URL added successfully', 'url' => $new_url, 'index' => array_key_last($urls)));
    } else {
        wp_send_json_error(array('message' => 'Invalid URL'));
    }
}
add_action('wp_ajax_vrs20_add_url', 'vrs20_add_url');

// AJAX handler for deleting URLs
function vrs20_delete_url() {
    check_ajax_referer('vrs20_add_url', 'nonce');
    $index = intval($_POST['index']);
    $urls = get_option('vrs20_stationbuilder_urls', array());
    if (isset($urls[$index])) {
        unset($urls[$index]);
        $urls = array_values($urls); // Re-index the array
        update_option('vrs20_stationbuilder_urls', $urls);
        wp_send_json_success(array('message' => 'URL deleted successfully'));
    } else {
        wp_send_json_error(array('message' => 'URL not found'));
    }
}
add_action('wp_ajax_vrs20_delete_url', 'vrs20_delete_url');

// AJAX handler for saving URL order
function vrs20_save_url_order() {
    check_ajax_referer('vrs20_add_url', 'nonce');
    $order = $_POST['order'];
    $urls = get_option('vrs20_stationbuilder_urls', array());
    $new_urls = array();
    foreach ($order as $index) {
        $index = intval($index);
        if (isset($urls[$index])) {
            $new_urls[] = $urls[$index];
        }
    }
    update_option('vrs20_stationbuilder_urls', $new_urls);
    wp_send_json_success(array('message' => 'URL order saved successfully'));
}
add_action('wp_ajax_vrs20_save_url_order', 'vrs20_save_url_order');

// Add URL Management page
function vrs20_add_url_management_page() {
    add_submenu_page(
        'edit.php?post_type=vrs20_stream',
        'Manage StationBuilder URLs',
        'Manage URLs',
        'manage_options',
        'vrs20_manage_urls',
        'vrs20_url_management_page'
    );
}
add_action('admin_menu', 'vrs20_add_url_management_page');

// URL Management page content
function vrs20_url_management_page() {
    if (isset($_POST['vrs20_add_url']) && wp_verify_nonce($_POST['vrs20_url_nonce'], 'vrs20_add_url')) {
        $new_url = esc_url_raw($_POST['vrs20_new_url']);
        if ($new_url) {
            $urls = get_option('vrs20_stationbuilder_urls', array());
            $urls[] = $new_url;
            update_option('vrs20_stationbuilder_urls', $urls);
            echo '<div class="updated"><p>URL added successfully!</p></div>';
        }
    }

    $urls = get_option('vrs20_stationbuilder_urls', array());
    ?>
    <div class="wrap">
        <h1>Manage StationBuilder URLs</h1>
        <form method="post" action="">
            <?php wp_nonce_field('vrs20_add_url', 'vrs20_url_nonce'); ?>
            <input type="url" name="vrs20_new_url" placeholder="Enter new URL" required>
            <input type="submit" name="vrs20_add_url" class="button button-primary" value="Add URL">
        </form>
        <h2>Current URLs:</h2>
        <ol>
            <?php foreach ($urls as $index => $url): ?>
                <li>
                    <span style="color: #0073aa;">URL <?php echo $index + 1; ?>:</span> 
                    <a href="<?php echo esc_url($url); ?>" target="_blank"><?php echo esc_url($url); ?></a> 
                    <span style="color: #46b450;">- Active</span>
                </li>
            <?php endforeach; ?>
        </ol>
    </div>
    <?php
}