<?php
/*
Plugin Name: VRS 2.0 Stream Manager
Description: Manage streams and embedded playlist content for VRS 2.0
Version: VRS2.0.1.18
Author: upRiver Studio - <a href="https://upriver.studio">https://upriver.studio</a>
*/

if (!defined('ABSPATH')) {
    exit;
}

// Include settings file
require_once plugin_dir_path(__FILE__) . 'stream-manager-settings.php';

// Register Custom Post Type
function vrs20_register_post_type() {
    $args = array(
        'public' => true,
        'label'  => 'VRS2.0 Streams',
        'supports' => array('title', 'editor', 'thumbnail'),
        'menu_icon' => 'dashicons-video-alt3',
        'has_archive' => true,
        'rewrite' => array('slug' => 'vrs20-streams'),
    );
    register_post_type('vrs20_stream', $args);
}
add_action('init', 'vrs20_register_post_type');

// Add meta boxes
function vrs20_add_meta_boxes() {
    add_meta_box('vrs20_stream_details', 'Stream Details', 'vrs20_stream_details_callback', 'vrs20_stream', 'normal', 'high');
}
add_action('add_meta_boxes', 'vrs20_add_meta_boxes');

function vrs20_stream_details_callback($post) {
    wp_nonce_field(basename(__FILE__), 'vrs20_stream_nonce');
    $stream_url = get_post_meta($post->ID, 'vrs20_stream_url', true);
    $stream_type = get_post_meta($post->ID, 'vrs20_stream_type', true);
    $stream_quality = get_post_meta($post->ID, 'vrs20_stream_quality', true);
    $stream_slug = get_post_meta($post->ID, 'vrs20_stream_slug', true);
    $stream_custom_url = get_post_meta($post->ID, 'vrs20_stream_custom_url', true);
    $stream_is_live = get_post_meta($post->ID, 'vrs20_stream_is_live', true);
    $stream_is_24_7 = get_post_meta($post->ID, 'vrs20_stream_is_24_7', true);
    $stream_is_playlist_maintained = get_post_meta($post->ID, 'vrs20_stream_is_playlist_maintained', true);
    $stream_storage = get_post_meta($post->ID, 'vrs20_stream_storage', true);
    $stream_playlist_features = get_post_meta($post->ID, 'vrs20_stream_playlist_features', true);
    
    // Output form fields
    echo '<p><label for="vrs20_stream_url">Stream URL:</label>';
    echo '<input type="text" name="vrs20_stream_url" id="vrs20_stream_url" value="' . esc_attr($stream_url) . '" size="50" /></p>';
    
    echo '<p><label for="vrs20_stream_type">Stream Type:</label>';
    echo '<select name="vrs20_stream_type" id="vrs20_stream_type">';
    echo '<option value="live" ' . selected($stream_type, 'live', false) . '>Live</option>';
    echo '<option value="vod" ' . selected($stream_type, 'vod', false) . '>Video on Demand</option>';
    echo '</select></p>';
    
    echo '<p><label for="vrs20_stream_quality">Stream Quality:</label>';
    echo '<select name="vrs20_stream_quality" id="vrs20_stream_quality">';
    echo '<option value="sd" ' . selected($stream_quality, 'sd', false) . '>SD</option>';
    echo '<option value="hd" ' . selected($stream_quality, 'hd', false) . '>HD</option>';
    echo '<option value="4k" ' . selected($stream_quality, '4k', false) . '>4K</option>';
    echo '</select></p>';

    echo '<p><label for="vrs20_stream_slug">Stream Slug:</label>';
    echo '<input type="text" name="vrs20_stream_slug" id="vrs20_stream_slug" value="' . esc_attr($stream_slug) . '" size="50" /></p>';

    echo '<p><label for="vrs20_stream_custom_url">Custom URL:</label>';
    echo '<input type="text" name="vrs20_stream_custom_url" id="vrs20_stream_custom_url" value="' . esc_attr($stream_custom_url) . '" size="50" /></p>';


    // Add player preview and embed options
    echo '<h3>Player Preview</h3>';
    echo vrs20_get_player_html($post->ID);

    echo '<h3>Embed Options</h3>';
    echo '<p><label for="vrs20_embed_code">Embed Code:</label>';
    echo '<textarea id="vrs20_embed_code" readonly rows="3" cols="50">' . esc_textarea(vrs20_get_embed_code($post->ID)) . '</textarea></p>';
    echo '<button type="button" onclick="vrs20CopyEmbedCode()">Copy Embed Code</button>';
}

// Function to get player HTML
function vrs20_get_player_html($post_id) {
    $stream_url = get_post_meta($post_id, 'vrs20_stream_url', true);
    $stream_type = get_post_meta($post_id, 'vrs20_stream_type', true);
    
    if (empty($stream_url)) {
        return '<p>No stream URL set.</p>';
    }
    
    $player_html = '<div class="vrs20-player">';
    if ($stream_type === 'live') {
        $player_html .= '<video id="vrs20-video-' . $post_id . '" controls autoplay>';
        $player_html .= '<source src="' . esc_url($stream_url) . '" type="application/x-mpegURL">';
        $player_html .= 'Your browser does not support the video tag.';
        $player_html .= '</video>';
    } else {
        $player_html .= '<video id="vrs20-video-' . $post_id . '" controls>';
        $player_html .= '<source src="' . esc_url($stream_url) . '" type="video/mp4">';
        $player_html .= 'Your browser does not support the video tag.';
        $player_html .= '</video>';
    }
    $player_html .= '</div>';
    
    return $player_html;
}

// Remove the fields from the Stream Details meta box
function vrs20_stream_details_meta_box($post) {
    wp_nonce_field('vrs20_save_stream_details', 'vrs20_stream_details_nonce');

    // Retrieve existing values
    $stream_urls = get_post_meta($post->ID, '_vrs20_stream_urls', true);

    ?>
    <p>
        <label for="vrs20_stream_urls">Stream URLs:</label><br>
        <textarea name="vrs20_stream_urls" id="vrs20_stream_urls" rows="3" cols="50"><?php echo esc_textarea($stream_urls); ?></textarea>
    </p>
    <?php
    // Remove the following fields:
    // - Is Live
    // - Is 24/7
    // - Is Playlist Maintained
    // - Storage Capacity
    // - Playlist Features
}

// Update the save_post function to remove the fields we no longer use
function vrs20_save_stream_details($post_id) {
    if (!isset($_POST['vrs20_stream_details_nonce']) || !wp_verify_nonce($_POST['vrs20_stream_details_nonce'], 'vrs20_save_stream_details')) {
        return;
    }

    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }

    if (!current_user_can('edit_post', $post_id)) {
        return;
    }

    // Save Stream URLs
    if (isset($_POST['vrs20_stream_urls'])) {
        update_post_meta($post_id, '_vrs20_stream_urls', sanitize_textarea_field($_POST['vrs20_stream_urls']));
    }

    // Remove the following fields:
    // - Is Live
    // - Is 24/7
    // - Is Playlist Maintained
    // - Storage Capacity
    // - Playlist Features
}
add_action('save_post_vrs20_stream', 'vrs20_save_stream_details');
// Function to get embed code
function vrs20_get_embed_code($post_id) {
    $embed_url = add_query_arg('embed', 'true', get_permalink($post_id));
    return '<iframe src="' . esc_url($embed_url) . '" width="640" height="360" frameborder="0" allowfullscreen></iframe>';
}

// Save post meta
function vrs20_save_post_meta($post_id) {
    if (!isset($_POST['vrs20_stream_nonce']) || !wp_verify_nonce($_POST['vrs20_stream_nonce'], basename(__FILE__))) {
        return $post_id;
    }
    
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return $post_id;
    }
    
    if (!current_user_can('edit_post', $post_id)) {
        return $post_id;
    }
    
    $fields = array('vrs20_stream_url', 'vrs20_stream_type', 'vrs20_stream_quality', 'vrs20_stream_slug', 'vrs20_stream_custom_url');
    
    foreach ($fields as $field) {
        if (isset($_POST[$field])) {
            update_post_meta($post_id, $field, sanitize_text_field($_POST[$field]));
        }
    }
}
add_action('save_post_vrs20_stream', 'vrs20_save_post_meta');

// Add custom columns to the admin list view
function vrs20_custom_columns($columns) {
    $columns['vrs20_stream_url'] = 'Stream URL';
    $columns['vrs20_stream_type'] = 'Stream Type';
    $columns['vrs20_stream_quality'] = 'Quality';
    $columns['vrs20_stream_slug'] = 'Slug';
    $columns['vrs20_stream_custom_url'] = 'Custom URL';
    return $columns;
}
add_filter('manage_vrs20_stream_posts_columns', 'vrs20_custom_columns');

// Populate custom columns in the admin list view
function vrs20_custom_column_content($column, $post_id) {
    switch ($column) {
        case 'vrs20_stream_url':
            echo esc_url(get_post_meta($post_id, 'vrs20_stream_url', true));
            break;
        case 'vrs20_stream_type':
            echo esc_html(get_post_meta($post_id, 'vrs20_stream_type', true));
            break;
        case 'vrs20_stream_quality':
            echo esc_html(get_post_meta($post_id, 'vrs20_stream_quality', true));
            break;
        case 'vrs20_stream_slug':
            echo esc_html(get_post_meta($post_id, 'vrs20_stream_slug', true));
            break;
        case 'vrs20_stream_custom_url':
            echo esc_url(get_post_meta($post_id, 'vrs20_stream_custom_url', true));
            break;
    }
}
add_action('manage_vrs20_stream_posts_custom_column', 'vrs20_custom_column_content', 10, 2);